==> docfbe_2_3_41_70.zip: docfbe_2_3_41_70/source/TCFbECustomDataLoader.h <==
/*
    TCFbECustomDataLoader.h    June 6, 2004.

    Copyright (C) 2003-2005 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#ifndef TCFbECustomDataLoaderH
#define TCFbECustomDataLoaderH
//---------------------------------------------------------------------------
#include <stdio.h>

#include "TCFbETypes.h"
#include "TCFbECustomCommandLineParser.h"
#include "TCFbEDataSetEx.h"
//---------------------------------------------------------------------------
class TCFbECustomDataLoader : public TObject
{
public:
    virtual __fastcall TCFbECustomDataLoader(TCFbECustomCommandLineParser* Parser, bool IsVerbose=false, int TotalProcess=1, int BeginProcess=4);    // RXgN^
    __fastcall ~TCFbECustomDataLoader();    // fXgN^

    TCFbEDataSetEx* LearningData;

    int    ErrorCode;    // G[R[hiG[Ȃꍇ 0
    AnsiString    ErrorParameter;    // G[p[^

protected:
    int CurrentProcess;
    int TotalProcess;

private:

};
//---------------------------------------------------------------------------
#endif

==> docfbe_2_3_46_82.zip: docfbe_2_3_46_82/source/TCFbECustomDataLoader.h <==
/*
    TCFbECustomDataLoader.h    June 6, 2004.

    Copyright (C) 2003-2005 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#ifndef TCFbECustomDataLoaderH
#define TCFbECustomDataLoaderH
//---------------------------------------------------------------------------
#include <stdio.h>

#include "TCFbETypes.h"
#include "TCFbECustomCommandLineParser.h"
#include "TCFbEDataSetEx.h"
//---------------------------------------------------------------------------
class TCFbECustomDataLoader : public TObject
{
public:
    virtual __fastcall TCFbECustomDataLoader(TCFbECustomCommandLineParser* Parser, bool IsVerbose=false, int TotalProcess=1, int BeginProcess=4);    // RXgN^
    __fastcall ~TCFbECustomDataLoader();    // fXgN^

    TCFbEDataSetEx* LearningData;

    int    ErrorCode;    // G[R[hiG[Ȃꍇ 0
    AnsiString    ErrorParameter;    // G[p[^

protected:
    int CurrentProcess;
    int TotalProcess;

    virtual TTargetColumnType __fastcall TargetColumnCheck(TCFbECustomCommandLineParser* Parser, int TargetIndex);

private:

};
//---------------------------------------------------------------------------
#endif
